@@ -1,6 +1,6 @@
 import click
 from pathlib import Path
-from flagg.interface import Lexer, Parser
+from flagg.interface import Lexer, Parser, SymbolTable
 from flagg.utils.errors import LexicalException, SyntaxException
 
 
@@ -9,10 +9,12 @@ from flagg.utils.errors import LexicalException, SyntaxException
 @click.argument("source", type=click.Path(exists=True, path_type=Path))
 @click.option("--output", type=click.Path(path_type=Path))
 @click.option("--verbose/--no-verbose", default=False)
-def cli(input, source, output, verbose):
+@click.option("--syntatic/--no-syntatic", default=False)
+def cli(input, source, output, verbose, syntatic):
 
-    lexer = Lexer.parse(input, verbose=verbose)
-    parser = Parser.parse(input, verbose=verbose)
+    lexer = Lexer.parse(input, verbose=False)
+    parser = Parser.parse(input, verbose=False)
+    table = SymbolTable()
 
     with open(source, "r") as file:
         code = file.read()
@@ -29,8 +31,11 @@ def cli(input, source, output, verbose):
             continue
 
         try:
-            tokens = lexer.run(line)
-            parser.validate(tokens)
+            tokens = lexer.run(line.strip())
+            table.append(index + 1, tokens)
+            
+            if (syntatic):
+                parser.validate(tokens)
         except SyntaxException as err:
             print(f"Syntax error on line {index}")
             exit(err)
@@ -40,7 +45,12 @@ def cli(input, source, output, verbose):
             print((" " * (err.args[1] - 1)) + "^")
             exit()
 
-    print(f"{len(lines)} lines of code were validated")
+    print(f"\n {len(lines)} lines of code were validated")
+
+    if verbose:
+        print("\n Symbol table:")
+        print(table)
+        print("\n")
 
     if output is not None:
         lexer.save(output)
